@@ -446,6 +446,13 @@ pub trait GeneralReadout {
         Err(STANDARD_NO_IMPL.clone())
     }
 
+    /// This function should return a list of available GPUs. \
+    ///
+    /// _e.g._ `["NVIDIA Corporation GeForce GTX 1650 Mobile / Max-Q"]`
+    fn gpus(&self) -> Result<Vec<aparato::PCIDevice>, ReadoutError> {
+        Err(STANDARD_NO_IMPL.clone())
+    }
+
     /// This function should return the average CPU usage over the last minute.
     fn cpu_usage(&self) -> Result<usize, ReadoutError> {
         Err(STANDARD_NO_IMPL.clone())
